@@ -13,7 +13,7 @@
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/03/09
- *    Last                 : 2007/10/14
+ *    Last                 : 2007/11/08
  * ====================================================================
  */
 
@@ -22,6 +22,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -33,14 +34,6 @@
 #include "CulcInputDlg.h"
 
 
-/*  フォーカスを entry に設定 */
-void def_focus(CULCINPUT_DLG *culcinput_dlg)
-{
-	gtk_window_set_focus(GTK_WINDOW(culcinput_dlg->dialog), culcinput_dlg->entry);
-}
-
-
-
 /* -------------------------------------------------------------------
  * Button Pushed
  */
@@ -52,11 +45,13 @@ void button_pushed(GtkWidget *widget, CULCINPUT_DLG *culcinput_dlg)
 	int start, end;
 	gboolean result;
 	int position;
+	char *get_char;
 	
 	
 	/* ボタンのラベルの文字をゲッツ */
 	str_button = gtk_button_get_label(GTK_BUTTON(widget));
 	
+	/* = */
 	if (strcmp(str_button, "=") == 0) {
 		/* テキストエントリーから文字列を取得 */
 		strcpy(str, gtk_entry_get_text(GTK_ENTRY(culcinput_dlg->entry)));
@@ -64,16 +59,57 @@ void button_pushed(GtkWidget *widget, CULCINPUT_DLG *culcinput_dlg)
 		d_value = StringCulc(str);
 		FloatOut_n(str, d_value, 6, 0);
 		gtk_entry_set_text(GTK_ENTRY(culcinput_dlg->entry), str);
+		gtk_editable_set_position (GTK_EDITABLE(culcinput_dlg->entry), -1);
 	}
+	/* C */
 	else if (strcmp(str_button, "C") == 0) {
 		str[0] = '\0';
 		gtk_entry_set_text(GTK_ENTRY(culcinput_dlg->entry), str);
 	}
+	/* . */
+	else if (strcmp(str_button, ".") == 0) {
+		/* 選択されていたら */
+		result = gtk_editable_get_selection_bounds(
+					GTK_EDITABLE(culcinput_dlg->entry), &start, &end);
+		if (result == TRUE) {
+			gtk_editable_delete_text (GTK_EDITABLE(culcinput_dlg->entry), start, end);
+		}
+		
+		
+		position = gtk_editable_get_position(GTK_EDITABLE(culcinput_dlg->entry));
+		//g_print("position = %d\n", position);
+		if (position == 0) {
+			gtk_editable_insert_text(GTK_EDITABLE(culcinput_dlg->entry), 
+						"0", 
+						1, 
+						&position);
+			gtk_editable_set_position (GTK_EDITABLE(culcinput_dlg->entry), position);
+		}
+		else {
+			get_char = gtk_editable_get_chars (GTK_EDITABLE(culcinput_dlg->entry),
+						position - 1, position);
+			//g_print("get_char = [%s]\n", get_char);
+			if (0x30 > get_char[0] || 0x39 < get_char[0]) {
+				gtk_editable_insert_text(GTK_EDITABLE(culcinput_dlg->entry), 
+							"0", 
+							1, 
+							&position);
+				gtk_editable_set_position (GTK_EDITABLE(culcinput_dlg->entry), position);
+			}
+		}
+		
+		position = gtk_editable_get_position(GTK_EDITABLE(culcinput_dlg->entry));
+		gtk_editable_insert_text(GTK_EDITABLE(culcinput_dlg->entry), 
+					str_button, 
+					strlen(str_button), 
+					&position);
+		gtk_editable_set_position (GTK_EDITABLE(culcinput_dlg->entry), position);
+	}
 	else {
-		result = gtk_editable_get_selection_bounds(GTK_EDITABLE(culcinput_dlg->entry), 
-					&start, &end);
+		/* 選択されていたら */
+		result = gtk_editable_get_selection_bounds(
+					GTK_EDITABLE(culcinput_dlg->entry), &start, &end);
 		if (result == TRUE) {
-			//g_print("TRUE\n");
 			gtk_editable_delete_text (GTK_EDITABLE(culcinput_dlg->entry), start, end);
 		}
 		position = gtk_editable_get_position(GTK_EDITABLE(culcinput_dlg->entry));
@@ -81,7 +117,7 @@ void button_pushed(GtkWidget *widget, CULCINPUT_DLG *culcinput_dlg)
 					str_button, 
 					strlen(str_button), 
 					&position);
-		gtk_editable_set_position (GTK_EDITABLE(culcinput_dlg->entry), -1);
+		gtk_editable_set_position (GTK_EDITABLE(culcinput_dlg->entry), position);
 	}
 }
 
@@ -124,79 +160,33 @@ void culcinput_dlg_ok_pushed(GtkWidget *widget, CULCINPUT_DLG *culcinput_dlg)
  */
 static gint culcinput_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event, CULCINPUT_DLG *culcinput_dlg)
 {
-//	g_print("sagcad.c : culcinput_dlg_key_press_event  state:%d  keyval:0x%x  length:%d  string:%s\n", 
-//			event->state, event->keyval, event->length, event->string);
-
-	if (event->keyval == 0xff0d || event->keyval == 0xff8d) {		/* Enter */
+	switch (event->keyval) {
+	case GDK_Return:
+	case GDK_KP_Enter:
 		culcinput_dlg_ok_pushed(widget, culcinput_dlg);
 		gtk_main_quit();
-	}
-	else if (event->keyval == 0xffff) {		/* Delete */
-		gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_CLEAR]));
+		break;
+	default:
+		break;
 	}
 	
 	switch (event->string[0]) {
-		case '0' : 
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_0]));
-			break;
-		case '1' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_1]));
-			break;
-		case '2' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_2]));
-			break;
-		case '3' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_3]));
-			break;
-		case '4' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_4]));
-			break;
-		case '5' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_5]));
-			break;
-		case '6' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_6]));
-			break;
-		case '7' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_7]));
-			break;
-		case '8' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_8]));
-			break;
-		case '9' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_9]));
-			break;
-		case '=' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_EQUAL]));
-			break;
-		case '.' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_DOT]));
-			break;
-		case '+' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_PURASU]));
-			break;
-		case '-' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_MAINASU]));
-			break;
-		case '*' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_KAKERU]));
-			break;
-		case '/' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_WARU]));
-			break;
-		case '(' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_OPEN]));
-			break;
-		case ')' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_CLOSED]));
-			break;
-		case 'C' :
-			gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_CLEAR]));
-			break;
-		default :
-			break;
+	case ' ' :
+	case '=' :
+		gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_EQUAL]));
+		return TRUE;
+		break;
+	case '.' :
+		gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_DOT]));
+		return TRUE;
+		break;
+	case 'C' :
+		gtk_button_clicked (GTK_BUTTON(culcinput_dlg->button[CID_BTN_CLEAR]));
+		break;
+	default:
+		break;
 	}
-	return TRUE; 
+	return FALSE;
 }
 
 
@@ -225,12 +215,15 @@ gint CulcInputDialog(CULCINPUT_DLG *culcinput_dlg)
 
 	/* ダイアログ(culcinput_dlg->dialog)生成 */
 	culcinput_dlg->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_position(GTK_WINDOW(culcinput_dlg->dialog), GTK_WIN_POS_MOUSE/*GTK_WIN_POS_CENTER*/);
-	gtk_window_set_title(GTK_WINDOW(culcinput_dlg->dialog), culcinput_dlg->title);
+	gtk_window_set_position(GTK_WINDOW(culcinput_dlg->dialog), 
+				GTK_WIN_POS_MOUSE/*GTK_WIN_POS_CENTER*/);
+	gtk_window_set_title(GTK_WINDOW(culcinput_dlg->dialog), 
+				culcinput_dlg->title);
 	/* ダイアログを最前面に表示する */
 	gtk_window_set_modal(GTK_WINDOW(culcinput_dlg->dialog), TRUE);
 	/* メインウィンドウを操作できないように設定 */
-	gtk_window_set_transient_for(GTK_WINDOW(culcinput_dlg->dialog), GTK_WINDOW(culcinput_dlg->parent));
+	gtk_window_set_transient_for(GTK_WINDOW(culcinput_dlg->dialog), 
+				GTK_WINDOW(culcinput_dlg->parent));
 	
 	g_signal_connect( G_OBJECT(culcinput_dlg->dialog), "key_press_event",
 				G_CALLBACK(culcinput_dlg_key_press_event), culcinput_dlg);
