@@ -13,7 +13,7 @@
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/01/30
- *    Last                 : 2007/10/11
+ *    Last                 : 2007/11/08
  * ====================================================================
  */
 
@@ -22,6 +22,8 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
+
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -59,9 +61,14 @@ static gint inputbox_delete_event(GtkWidget *widget, GdkEventAny *event, gpointe
 
 static gboolean inputbox_key_pressed(GtkWidget *widget, GdkEventKey *event, input_box *ibox)
 {
-	if (event->keyval == 0xff0d || event->keyval == 0xff8d) {
+	switch (event->keyval) {
+	case GDK_Return:
+	case GDK_KP_Enter:
 		inputbox_ok_pushed(widget, ibox);
 		gtk_main_quit();
+		break;
+	default:
+		break;
 	}
 	return FALSE;
 }
