@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2006 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2006 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/04/12
- *    Last                 : 2006/05/25
+ *    Last                 : 2007/11/08
  * ====================================================================
  */
 #ifndef __PRINTSETDLG_H__
@@ -26,7 +26,7 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 1 :   (struct #define etc)
+ * 1 : 前処理  (struct #define etc)
  * -------------------------------------------------------
  */
 
@@ -35,7 +35,7 @@ struct _PRINTSET_DLG
 	gint value;					/* 0:cancel  1:OK */
 	gint view;					/* 0:display  1:drawing */
 	gint paper;					/* a4:1  a3:2  b5:3  b4:4 */
-	gint orientation;			/* :0:portrait   :1:landscape */
+	gint orientation;			/* 縦:0:portrait   横:1:landscape */
 	gdouble up_scale;
 	gdouble low_scale;
 
@@ -63,16 +63,16 @@ typedef struct _PRINTSET_DLG PRINTSET_DLG;
 
 
 /* -------------------------------------------------------
- * 2 : ѿ (global)
+ * 2 : 外部変数 (global)
  * -------------------------------------------------------
  */
 #ifdef _PRINTSETDLG_
 #define   GLOBAL
-/*  */
+/* 初期値設定 */
 #define   GLOBAL_VAL(v)  = (v)
 #else
 #define   GLOBAL	extern
-/* ʬ̵ */
+/* 初期値設定の代入部分を無くす */
 #define   GLOBAL_VAL(v)  /* */
 #endif
 
@@ -86,11 +86,11 @@ typedef struct _PRINTSET_DLG PRINTSET_DLG;
 
 
 /* -------------------------------------------------------
- * 3 : ؿ (Function)
+ * 3 : 外部関数 (Function)
  * -------------------------------------------------------
  */
 
-/*  */
+/* 印刷設定 */
 gint PrintSetDialog(PRINTSET_DLG *printset_dlg);
 
 
@@ -100,7 +100,7 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg);
 #endif /* __cplusplus */
 #endif /* __PRINTSETDLG_H__ */
 /* ====================================================================
- * ===  Copyright (C) 1998-2006 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : PrintSetDlg.h
