@@ -13,7 +13,7 @@
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/02/19
- *    Last                 : 2007/10/11
+ *    Last                 : 2007/11/08
  * ====================================================================
  */
 #ifndef __TURNDLG_H__
@@ -26,17 +26,17 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 1 :   (struct #define etc)
+ * 1 : 前処理  (struct #define etc)
  * -------------------------------------------------------
  */
 
 struct _TURN_DLG
 {
 	gint value;
-	gdouble x_pos;				/*  */
-	gdouble y_pos;				/*  */
-	gdouble angle;				/*  */
-	gint repeats;				/*  */
+	gdouble x_pos;				/* 原点Ｘ */
+	gdouble y_pos;				/* 原点Ｙ */
+	gdouble angle;				/* 角度 */
+	gint repeats;				/* 回数 */
 
 	GtkWidget *x_pos_entry;
 	GtkWidget *y_pos_entry;
@@ -50,16 +50,16 @@ typedef struct _TURN_DLG TURN_DLG;
 
 
 /* -------------------------------------------------------
- * 2 : ѿ (global)
+ * 2 : 外部変数 (global)
  * -------------------------------------------------------
  */
 #ifdef _TURNDLG_
 #define   GLOBAL
-// 
+// 初期値設定
 #define   GLOBAL_VAL(v)  = (v)
 #else
 #define   GLOBAL	extern
-// ʬ̵
+// 初期値設定の代入部分を無くす
 #define   GLOBAL_VAL(v)  /* */
 #endif
 
@@ -73,10 +73,10 @@ typedef struct _TURN_DLG TURN_DLG;
 
 
 /* -------------------------------------------------------
- * 3 : ؿ (Function)
+ * 3 : 外部関数 (Function)
  * -------------------------------------------------------
  */
-/* ԡڰư/ʣ̡ */
+/* コピー【移動/複写】設定 */
 gint TurnDialog(TURN_DLG *turn_dlg);
 
 
